'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var path = require('path');
var fs = require('fs-extra');
var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var pluginScaffolderNode = require('@backstage/plugin-scaffolder-node');
var backendCommon = require('@backstage/backend-common');
var yaml = require('js-yaml');
var zod = require('zod');
var k8sApply = require('k8s-apply');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var path__default = /*#__PURE__*/_interopDefaultLegacy(path);
var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var yaml__namespace = /*#__PURE__*/_interopNamespace(yaml);

const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "deploy:kubernetes",
    description: "Deploys Kubernetes manifests.",
    schema: {
      input: zod.z.object({
        sourcePath: zod.z.string().optional(),
        targetPath: zod.z.string().optional(),
        authToken: zod.z.string().describe("Authentication token to access the Kubernetes cluster"),
        clusterUrl: zod.z.string().describe("URL of the Kubernetes cluster")
      })
    },
    async handler(ctx) {
      const { sourcePath, targetPath, authToken, clusterUrl } = ctx.input;
      try {
        const fileRoot = sourcePath ? backendCommon.resolveSafeChildPath(ctx.workspacePath, sourcePath) : ctx.workspacePath;
        const directoryContents = await pluginScaffolderNode.serializeDirectoryContents(fileRoot);
        const yamlFiles = directoryContents.filter(
          (file) => file.path.endsWith(".yaml") || file.path.endsWith(".yml")
        ).map(
          (file) => targetPath ? path__default["default"].posix.join(targetPath, file.path) : file.path
        );
        for (const filePath of yamlFiles) {
          let manifestYaml = "";
          let manifestObject;
          try {
            manifestYaml = await fs__default["default"].promises.readFile(filePath, {
              encoding: "utf-8"
            });
            manifestObject = yaml__namespace.load(manifestYaml);
          } catch (error) {
            ctx.logger.error(`Error processing file: ${filePath}`, error);
            continue;
          }
          try {
            const response = await k8sApply.applyObject(manifestObject, {
              server: clusterUrl,
              token: authToken
            });
            ctx.logger.info(
              `Deployment response for ${filePath}: ${JSON.stringify(response)}`
            );
          } catch (error) {
            ctx.logger.error(`Deployment failed for ${filePath}: ${error}`);
          }
        }
      } catch (error) {
        ctx.logger.error("An error occurred during deployment:", error);
        throw error;
      }
    }
  });
};

exports.deployKubernetesAction = deployKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
